@@ -5,7 +5,7 @@
 # .author     : Fabrizio Pollastri
 # .site	      : Revello - Italy
 # .creation   :	3-Nov-2006
-# .copyright  :	(c) 2006-2008 Fabrizio Pollastri
+# .copyright  :	(c) 2006-2011 Fabrizio Pollastri
 # .license    : GNU General Public License (see below)
 #
 # This file is part of "AVC, Application View Controller".
@@ -39,11 +39,17 @@ class error(Exception):
     return repr(self.value)
 
 
+## module information
+__author__ = 'Fabrizio Pollastri <f.pollastri@inrim.it>'
+__license__ = '>= GPL v3'
+__version__ = '0.8.3'
+
+
 ## load proper AVC widget toolkit binding according with the widget toolkit
 # imported by application program
 
 # supported toolkit names indexed by python binding module names
-TOOLKITS = { 'gtk':'GTK+','qt':'Qt3','PyQt4':'Qt4','javax':'SWING', \
+TOOLKITS = { 'gtk':'GTK+','qt':'Qt3','PyQt4':'Qt4','javax':'Swing', \
   'Tkinter':'Tkinter','wx':'wxWidgets'}
 
 # avc toolkit bindings indexed by python binding module names
@@ -73,8 +79,10 @@ WIDGET_NAME_SEP = '__'
 # AVC common data
 class AVCCD:
   def __init__(self):
+    self.toolkit_version = ''
     self.verbosity = 0
     self.view_period = 0.1
+    self.widget_map = {}
     self.cogets = {}
     self.connections = {}
     self.connections_updates = {}
@@ -100,10 +108,14 @@ class AVC(object):
     except:
       pass
 
+    # do init specific to widget toolkit
+    real.init(globals())
+
     # if verbosity > 0 , print header
     if avccd.verbosity > 0:
-      print 'AVC ' + '0.6.0' + ' - Activity Report'
-      print 'widget toolkit binding: ' + TOOLKITS[toolkit]
+      print 'AVC ' + __version__ + ' - Activity Report'
+      print 'widget toolkit binding: ' + TOOLKITS[toolkit] + ' v' \
+        + avccd.toolkit_version
       print 'program: ' + sys.argv[0]  
       print 'verbosity: ' + str(avccd.verbosity)
       if avccd.view_period:
@@ -112,16 +124,13 @@ class AVC(object):
       else:
         print 'connection update mode: immediate'
 
-    # do init specific to widget toolkit
-    real.init(avccd.verbosity,view_period)
-
     # connect widgets-variables in __main__ namespace
     self.avc_connect(real.toplevel_widgets())
 
     # if a sampled (periodic) update of all controls views is required,
     # start a periodic call to view update function.
     if avccd.view_period != 0.0:
-      avccd.timer = real.timer(view_update,avccd.view_period)
+      avccd.timer = real.timer(self.view_update,avccd.view_period)
 
 
   def avc_connect(self,toplevel):
@@ -130,6 +139,10 @@ class AVC(object):
     an attribute of object_ object, create a widget-attribute connection.
     """
 
+    # check for avc_init execution
+    if not avccd.widget_map:
+      raise error, "avc_connect must be called after avc_init call."
+
     # force top level widgets to be a list
     if toplevel.__class__ != list:
       toplevel = [toplevel]
@@ -138,10 +151,10 @@ class AVC(object):
       print 'widget tree scansion from top level ' + str(toplevel)
 
     # for each widget in GUI ... 
-    for widget, widget_name in get_widget(toplevel):
+    for widget, widget_name in self.get_widget(toplevel):
 
       # if widget is not supported: go to next widget
-      if not real.WIDGETS_MAP.has_key(widget.__class__):
+      if not avccd.widget_map.has_key(widget.__class__):
 
         if avccd.verbosity > 3:
 	  print '  skip unsupported widget ' + \
@@ -183,39 +196,37 @@ class AVC(object):
       avccd.connected_widgets[widget] = connection
 
 
-# core functions
-
-def get_widget(widgets):
-  """
-  Widget tree iterator. Start from toplevel widgets and traverse their
-  widgets trees in breath first mode returning for each widget its
-  pointer and name.
-  """
-  # for each toplevel widget ...
-  while widgets:
-    children = []
-    # for each widget in this level ...
-    for widget in widgets:
-      # return pointer and name of widget
-      yield (widget,real.widget_name(widget))
-      children += real.widget_children(widget)
-      # children of this level are widgets of next level
-      widgets = children
+  def get_widget(self,widgets):
+    """
+    Widget tree iterator. Start from toplevel widgets and traverse their
+    widgets trees in breath first mode returning for each widget its
+    pointer and name.
+    """
+    # for each toplevel widget ...
+    while widgets:
+      children = []
+      # for each widget in this level ...
+      for widget in widgets:
+        # return pointer and name of widget
+        yield (widget,real.widget_name(widget))
+        children += real.widget_children(widget)
+        # children of this level are widgets of next level
+        widgets = children
 
 
-def view_update():
-  "Periodically update views for all scheduled cogets"
+  def view_update(self):
+    "Periodically update views for all scheduled cogets"
 
-  for connection in avccd.connections_updates.keys():
-    setter = avccd.connections_updates[connection]
-    # set the new control value in all widgets binded to this control
-    # excluding the setting widget, if setter is a widget.
-    for wal_widget in connection.wal_widgets:
-      if wal_widget != setter:
-        wal_widget.write(connection.control_value)
+    for connection in avccd.connections_updates.keys():
+      setter = avccd.connections_updates[connection]
+      # set the new control value in all widgets binded to this control
+      # excluding the setting widget, if setter is a widget.
+      for wal_widget in connection.wal_widgets:
+        if wal_widget != setter:
+          wal_widget.write(connection.control_value)
 
-  # clear all update requests
-  avccd.connections_updates = {}
+    # clear all update requests
+    avccd.connections_updates = {}
 
 
 class Connection:
@@ -269,7 +280,7 @@ class Connection:
           print '    connected handler '+'"'+control_name+'_changed"'
 
     # map the connected widget into the corresponding abstract widget
-    wal_widget = eval(real.WIDGETS_MAP[widget.__class__])
+    wal_widget = avccd.widget_map[widget.__class__]
 
     if avccd.verbosity > 1:
       print '  add widget ' + widget.__class__.__name__ + \
