@@ -39,9 +39,27 @@ def toplevel_widgets():
   "Return the list of all top level widgets"
   return [wx.GetApp().GetTopWindow()]
 
-def init(*args,**kwargs):
+def init(core):
   "Do init specific to this widget toolkit"
-  pass
+  # mapping between the real widget and the wal widget
+  core['avccd'].widget_map = { \
+    wx.BitmapButton:	core['Button'], \
+    wx.Button:		core['Button'], \
+    wx.CheckBox:	core['ToggleButton'], \
+    wx.ComboBox:	core['ComboBox'],\
+    wx.Choice:		core['ComboBox'],\
+    wx.Gauge:		core['ProgressBar'], \
+    wx.ListCtrl:	core['ListView'], \
+    wx.RadioBox:	core['RadioButton'], \
+    wx.Slider:		core['Slider'], \
+    wx.SpinCtrl:	core['SpinButton'], \
+    wx.StaticText:	core['Label'], \
+    wx.StatusBar:	core['StatusBar'],
+    wx.TextCtrl:	core['Entry'],
+    wx.ToggleButton:	core['ToggleButton'], \
+    wx.TreeCtrl:	core['TreeView']}
+  # get toolkit version
+  core['avccd'].toolkit_version = wx.VERSION_STRING
 
 def widget_children(widget):
   "Return the list of all children of the widget"
@@ -226,6 +244,7 @@ class ListView(ListTreeView):
       for col_num in range(self.widget.GetColumnCount()):
         col_item = self.widget.GetColumn(col_num)
         col_item.SetText(value['head'][col_num])
+        self.widget.SetColumn(col_num,col_item)
     # set data rows
     body = value['body']
     self.widget.DeleteAllItems()
@@ -371,7 +390,7 @@ class TreeView(ListTreeView):
         % self.widget.__class__.__name__
     key,row = self.connection.control_value.get('body',None).iteritems().next()
     if type(row) == list and not len(row) == 1:
-      raise error,"%s widget do not allow data rows with mode than one column."\
+      raise error,"%s widget do not allow data rows with more than one column."\
         % self.widget.__class__.__name__
 
     # connect relevant signals
@@ -392,9 +411,9 @@ class TreeView(ListTreeView):
         body[string.join(map(str,node_path),'.')] = \
           self.row_types[0](self.widget.GetItemText(node_id))
       except:
-        if self.row_types[col_num] == int:
+        if self.row_types[0] == int:
           body[string.join(map(str,node_path),'.')] = [0]
-        elif self.row_types[col_num] == float:
+        elif self.row_types[0] == float:
           body[string.join(map(str,node_path),'.')] = [0.0]
       child_id,child = self.widget.GetFirstChild(node_id)
       child_num = 1
@@ -417,31 +436,12 @@ class TreeView(ListTreeView):
     pass
 
   def root_node(self):
-    "Return the root node of the tree"
+    "Clean tree and return the root node"
+    self.widget.DeleteAllItems()
     return self.widget.AddRoot('')
 
   def add_node(self,parent,last_node,current_depth,data):
     "Add current node to the tree"
     return self.widget.AppendItem(parent,str(data))
 
-
-## mapping between the real widget and the wal widget
-
-WIDGETS_MAP = { \
-  wx.BitmapButton:	'Button', \
-  wx.Button:		'Button', \
-  wx.CheckBox:		'ToggleButton', \
-  wx.ComboBox:		'ComboBox',\
-  wx.Choice:		'ComboBox',\
-  wx.Gauge:		'ProgressBar', \
-  wx.ListCtrl:		'ListView', \
-  wx.RadioBox:		'RadioButton', \
-  wx.Slider:		'Slider', \
-  wx.SpinCtrl:		'SpinButton', \
-  wx.StaticText:	'Label', \
-  wx.StatusBar:		'StatusBar',
-  wx.TextCtrl:		'Entry',
-  wx.ToggleButton:	'ToggleButton', \
-  wx.TreeCtrl:		'TreeView'}
- 
 #### END
